package com.qr.flutter_toolkit;

import android.content.Intent;

import com.qr.flutter_toolkit.gps_location.GPSLocationHandler;
import com.qr.flutter_toolkit.package_info.PackageInfoHandler;
import com.qr.flutter_toolkit.permission_handler.PermissionHandler;
import com.qr.flutter_toolkit.path_provider.PathProviderHandler;

import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * FlutterToolkitPlugin
 */
public class FlutterToolkitPlugin {
    private final static String TOOLKIT_PATH_PROVIDER_METHODS = "com.qr.flutter_toolkit/path_provider/methods";
    private final static String TOOLKIT_PACKAGE_INFO_METHODS = "com.qr.flutter_toolkit/package_info/methods";
    private final static String TOOLKIT_GEOLOCATION_METHODS = "com.qr.flutter_toolkit/gps_location/methods";
    private final static String TOOLKIT_GEOLOCATION_EVENTS = "com.qr.flutter_toolkit/gps_location/events";
    private final static String TOOLKIT_PERMISSION_METHODS = "com.qr.flutter_toolkit/permission/methods";

    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        MethodChannel pathProviderMethodChannel = new MethodChannel(registrar.messenger(), TOOLKIT_PATH_PROVIDER_METHODS);
        pathProviderMethodChannel.setMethodCallHandler(new PathProviderHandler(registrar));

        MethodChannel packageInfoMethodChannel = new MethodChannel(registrar.messenger(), TOOLKIT_PACKAGE_INFO_METHODS);
        packageInfoMethodChannel.setMethodCallHandler(new PackageInfoHandler(registrar));

        MethodChannel geolocationMethodChannel = new MethodChannel(registrar.messenger(), TOOLKIT_GEOLOCATION_METHODS);
        EventChannel geolocationEventChannel = new EventChannel(registrar.messenger(), TOOLKIT_GEOLOCATION_EVENTS);
        GPSLocationHandler GPSLocationHandler = new GPSLocationHandler(registrar);
        geolocationMethodChannel.setMethodCallHandler(GPSLocationHandler);
        geolocationEventChannel.setStreamHandler(GPSLocationHandler);

        MethodChannel permissionMethodChannel = new MethodChannel(registrar.messenger(), TOOLKIT_PERMISSION_METHODS);
        PermissionHandler permissionHandler = new PermissionHandler(registrar);
        permissionMethodChannel.setMethodCallHandler(permissionHandler);

        registrar.addRequestPermissionsResultListener(new PluginRegistry.RequestPermissionsResultListener() {
            @Override
            public boolean onRequestPermissionsResult(int id, String[] permissions, int[] grantResults) {
                if (id == PermissionHandler.PERMISSION_CODE) {
                    permissionHandler.onRequestPermissionsResult(id, permissions, grantResults);
                    return true;
                }
                return false;
            }
        });
        registrar.addActivityResultListener(new PluginRegistry.ActivityResultListener() {
            @Override
            public boolean onActivityResult(int requestCode, int responseCode, Intent intent) {
                if (requestCode == PermissionHandler.PERMISSION_CODE_IGNORE_BATTERY_OPTIMIZATIONS) {
                    permissionHandler.onActivityResult(requestCode, responseCode, intent);
                    return true;
                } else if (requestCode == PermissionHandler.PERMISSION_CODE_SYSTEM_ALERT_WINDOW) {
                    permissionHandler.onActivityResult(requestCode, responseCode, intent);
                } else if(requestCode == PermissionHandler.PERMISSION_CODE_REQUEST_INSTALL_PACKAGES){
                    permissionHandler.onActivityResult(requestCode,responseCode,intent);
                }
                return false;
            }
        });
    }
}
